===============
Release History
===============

`0.0.3`_ (22 Feb 2018)
----------------------
- Made ``divak_request_id`` attribute available in all log records.
- Added logging of the divak request ID in Tornado access log.

`0.0.2`_ (10 Feb 2018)
----------------------
- Implemented correlation header relaying via
  :class:`divak.api.RequestIdPropagator`.

`0.0.1`_ (4 Feb 2018)
---------------------
- Worked out the Circle-CI build process.
- No content changes.

`0.0.0`_ (4 Feb 2018)
---------------------
- Initial tag to verify end-to-end pipeline.

.. _Next Release: https://github.com/dave-shawley/divak-tornado/compare/0.0.3...head
.. _0.0.3: https://github.com/dave-shawley/divak-tornado/compare/0.0.2...0.0.3
.. _0.0.2: https://github.com/dave-shawley/divak-tornado/compare/0.0.1...0.0.2
.. _0.0.1: https://github.com/dave-shawley/divak-tornado/compare/0.0.0...0.0.1
.. _0.0.0: https://github.com/dave-shawley/divak-tornado/releases/tag/0.0.0
